rriskFitdist.cont(data, distr, method = c("mle", "mme"), start, chisqbreaks, meancount, ...)name naming a distribution for which the corresponding
density function dname, the corresponding distribution function
pname and the corresponding quantile function must be defined, or
directly the density function.method = "mme",
and may be omitted for some distributions for which reasonable starting values
are computed if method = "mle".meancount, or slightly more if
there are some ties.rriskMLEdist, in order to control the optimization method.rriskFitdist.cont returns a list containing 19 items with following fitting results:
estimatemethodsdNULL in case of the "mme" method.corNULL in case of the "mme" method.loglikNULL in case of the "mme" method.aicNULL in case of the "mme" method.bicNULL in case of the "mme" method.ndatadistnamechisqNULL, if not computed.chisqbreakschisqpvalueNULL, if not computed.chisqdfNULL, if not computed.chisqtableadNULL, if not computed.adtestNULL, if not computed.ksNULL, if not computed.kstestNULL, if not computed.fitdist from the package
fitdistrplus (Version 0.1-2). The original function was extended to
fitting additional distributions. The following continuous distributions can
be fitted by this function: normal, lognormal, logistic, exponential, F,
Student's t, Beta, Cauchy, Weibull, Gamma.
For more details see the assistance page of the function
fitdist from the package fitdistrplus.
This function is not intended to be called directly but is internally
called in useFitdist.
set.seed(1)
x <- stats::rnorm(5000, mean = 10, sd = 5)
rriskFitdist.cont(x, "norm")
rriskFitdist.cont(x, "t")
Run the code above in your browser using DataLab